@@ -3,7 +3,7 @@
 ** Purpose:     wxWidgets wrapper around the SQLite3 embedded database library.
 ** Author:      Ulrich Telle
 ** Created:     2005-07-14
-** Copyright:   (c) 2005-2018 Ulrich Telle
+** Copyright:   (c) 2005-2020 Ulrich Telle
 ** License:     LGPL-3.0+ WITH WxWindows-exception-3.1
 */
 
@@ -44,6 +44,66 @@
 
 <dl>
 
+<dt><b>4.5.1</b> - <i>January 2020</i></dt>
+<dd>
+Upgrade to SQLite version 3.31.1<br>
+
+</dd>
+<dt><b>4.5.0</b> - <i>January 2020</i></dt>
+<dd>
+Upgrade to SQLite version 3.31.0<br>
+Modified API for wxSQLite3Database::CreateFunction methods<br>
+
+</dd>
+<dt><b>4.4.8</b> - <i>October 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.30.1<br>
+Adjusted encryption extension to support SQLite's shared cache mode<br>
+
+</dd>
+<dt><b>4.4.7</b> - <i>October 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.30.0<br>
+
+</dd>
+<dt><b>4.4.6</b> - <i>September 2019</i></dt>
+<dd>
+Fixed missing cipher application in method wxSQLite3Database::ReKey<br>
+
+</dd>
+<dt><b>4.4.5</b> - <i>August 2019</i></dt>
+<dd>
+Fixed broken compatibility with wxWidgets 2.8.12<br>
+
+</dd>
+<dt><b>4.4.4</b> - <i>August 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.29.0<br>
+Added SQLite logging support<br>
+Added build support for VS2019<br>
+Added CMake support (PR #63)<br>
+Updated build files to overcome problems with static builds (issue #73)<br>
+Eliminated duplication of error messages for different wxWidgets builds (PR #64)<br>
+Fixed missing call to progress callback in wxSQLite3Database::Restore (PR #66)<br>
+Fixed issue #58 with silently failing wxSQLite3Transaction::Commit method<br>
+Fixed issue with named collections which could result in crashes (PR #59)<br>
+
+</dd>
+<dt><b>4.4.3</b> - <i>May 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.28.0<br>
+
+</dd>
+<dt><b>4.4.2</b> - <i>February 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.27.2<br>
+
+</dd>
+<dt><b>4.4.1</b> - <i>February 2019</i></dt>
+<dd>
+Upgrade to SQLite version 3.27.1<br>
+
+</dd>
 <dt><b>4.4.0</b> - <i>December 2018</i></dt>
 <dd>
 Upgrade to SQLite version 3.26.0<br>
@@ -594,6 +654,7 @@ The following people have contributed to wxSQLite3:
 <li>Francesco Montorsi (enhancement of the build system)</li>
 <li>Neville Dastur (enhancement of the method TableExists)</li>
 <li>Tobias Langner (RAII class for managing transactions)</li>
+<li>Deamhan (CMake support and various bug fixes)</li>
 </ul>
 
  */
